@@ -115,7 +115,8 @@ journal entry (refer to the `tmr' package on GNU ELPA)."
   :type 'hook)
 
 (defun denote-journal-directory ()
-  "Make the variable `denote-journal-directory' and its parents."
+  "Return the variable `denote-journal-directory' as a directory.
+If the path does not exist, then make it first."
   (if-let* (((stringp denote-journal-directory))
             (directory (file-name-as-directory (expand-file-name denote-journal-directory))))
       (progn
@@ -239,7 +240,8 @@ If there are multiple journal entries for the date, prompt for one among
 them using minibuffer completion.  If there is only one, return it.  If
 there is no journal entry, create it."
   (let* ((internal-date (or (denote-valid-date-p date) (current-time)))
-         (files (denote-journal--entry-today internal-date)))
+         (files (denote-journal--entry-today internal-date))
+         (denote-kill-buffers nil))
     (if files
         (denote-journal-select-file-prompt files)
       (save-window-excursion
@@ -256,7 +258,7 @@ A journal entry is one that has the value of the variable
 If there are multiple journal entries for the current date,
 prompt for one using minibuffer completion.  If there is only
 one, visit it outright.  If there is no journal entry, create one
-by calling `denote-journal-extra-new-entry'.
+by calling `denote-journal-new-entry'.
 
 With optional DATE as a prefix argument, prompt for a date.  If
 `denote-date-prompt-use-org-read-date' is non-nil, use the Org
@@ -280,7 +282,7 @@ A journal entry is one that has the value of the variable
 If there are multiple journal entries for the current date,
 prompt for one using minibuffer completion.  If there is only
 one, link to it outright.  If there is no journal entry, create one
-by calling `denote-journal-extra-new-entry' and link to it.
+by calling `denote-journal-new-entry' and link to it.
 
 With optional DATE as a prefix argument, prompt for a date.  If
 `denote-date-prompt-use-org-read-date' is non-nil, use the Org
@@ -305,7 +307,10 @@ file's title.  This has the same meaning as in `denote-link'."
 
 ;;;; Integration with the `calendar'
 
-(defface denote-journal-calendar '((t :box (:line-width (-1 . -1))))
+(defface denote-journal-calendar
+  '((((supports :box t))
+     :box (:line-width (-1 . -1)))
+    (t :inverse-video t))
   "Face to mark a Denote journal entry in the `calendar'.")
 
 (defun denote-journal-calendar--file-to-date (file)
@@ -317,7 +322,7 @@ file's title.  This has the same meaning as in `denote-link'."
       (list month day year))))
 
 (defun denote-journal-calendar--get-files (calendar-date)
-  "Return files around CALENDAR-DATE in variable `denote-journal-keyword'."
+  "Return files around CALENDAR-DATE in variable `denote-journal-directory'."
   (pcase-let* ((denote-directory (denote-journal-directory))
                (interval (calendar-interval
                           displayed-month displayed-year ; These are local to the `calendar'
@@ -325,9 +330,11 @@ file's title.  This has the same meaning as in `denote-link'."
                           (calendar-extract-year calendar-date)))
                (`(,current-month ,_ ,current-year) calendar-date)
                (`(,previous-month . ,previous-year) (calendar-increment-month-cons (- interval 1)))
+               (`(,previous-month-2 . ,previous-year-2) (calendar-increment-month-cons (- interval 2)))
                (`(,next-month . ,next-year) (calendar-increment-month-cons (+ interval 1)))
-               (years (list previous-year current-year next-year))
-               (months (list previous-month current-month next-month))
+               (`(,next-month-2 . ,next-year-2) (calendar-increment-month-cons (+ interval 2)))
+               (years (list previous-year-2 previous-year current-year next-year next-year-2))
+               (months (list previous-month-2 previous-month current-month next-month next-month-2))
                (time-regexp (concat (regexp-opt (mapcar #'number-to-string years))
                                     (regexp-opt (mapcar (lambda (number) (format "%02d" number)) months))))
                (keyword-regexp (denote-journal--keyword-regex)))
@@ -345,7 +352,8 @@ file's title.  This has the same meaning as in `denote-link'."
               (files (denote-journal-calendar--get-files date))
               (dates (delq nil (mapcar #'denote-journal-calendar--file-to-date files))))
     (dolist (date dates)
-      (calendar-mark-visible-date date 'denote-journal-calendar))))
+      (when (calendar-date-is-visible-p date)
+        (calendar-mark-visible-date date 'denote-journal-calendar)))))
 
 (defun denote-journal-calendar--date-to-time (calendar-date)
   "Return internal time of `calendar' CALENDAR-DATE.
@@ -401,10 +409,9 @@ among them."
 Add the function `denote-journal-calendar-mode' to the
 `calendar-mode-hook' for changes to take effect."
   :global nil
-  (if denote-journal-calendar-mode
-      (dolist (hook '(calendar-today-visible-hook calendar-today-invisible-hook))
-        (add-hook hook #'denote-journal-calendar-mark-dates nil :local))
-    (dolist (hook '(calendar-today-visible-hook calendar-today-invisible-hook))
+  (dolist (hook '(calendar-today-visible-hook calendar-today-invisible-hook))
+    (if denote-journal-calendar-mode
+        (add-hook hook #'denote-journal-calendar-mark-dates nil :local)
       (remove-hook hook #'denote-journal-calendar-mark-dates :local))))
 
 (provide 'denote-journal)
